import { Table, Pagination, Switch } from 'antd'
import { useEffect, useState } from 'react'
import dayjs from 'dayjs'
import { throttle } from 'lodash'
import styles from './index.module.css'
import adTypeState from '@src/store/globalStates/adTypeState'
import type { ColumnsType } from 'antd/es/table'
import type { 
  PropsType, RowDataType, 
  PaginationOnChangeType, TableOnChangeType 
} from './types'

export default function ContentTable ({
  tableData,
  total,
  pageNumber,
  pageSize,
  onTableChange,
  onPaginationChange,
  onSwitchStatus,
}:PropsType) {
  const [height, setHeight] = useState(500)
  const adTypes = adTypeState.useGlobalState()  
  const adTypeMap = Object.entries(adTypes || {}).reduce((obj,[name,{code}])=>{
    obj[code] = name
    return obj
  }, {} as MapType<string>)

  useEffect(()=>{
    const otherHeight = 60 + 64 + 48 + 48 + 55 // 预留的高度
    setHeight(window.innerHeight - otherHeight)
    const resizeEvent =throttle((e)=>{
      setHeight(e.target.innerHeight - otherHeight)
    },300)
    window.addEventListener('resize',resizeEvent)
    return ()=> window.removeEventListener('resize',resizeEvent)
  },[])
 
  const columns:ColumnsType<RowDataType> = [
    {
      title: '广告位名称',
      dataIndex: 'unionAdName',
    },
    {
      title: '广告位ID',
      dataIndex: 'unionAdId',
    },
    {
      title: '所属应用',
      dataIndex: 'unionAppName',
    },
    {
      title: '广告位类型',
      dataIndex: 'unionAdPosition',
      render: (v) => adTypeMap[v] || v
    },
    {
      title: '状态',
      dataIndex: 'status',
      render:(v,row) => (
        <Switch checked={v} onChange={(checked) => onSwitchStatus({checked,row}) }/>
      )
    },
    {
      title: '创建时间',
      dataIndex: 'createTime',
      render: (v) => dayjs(v).format('YYYY-MM-DD HH:mm:ss')
    }
  ]

  const paginationChange:PaginationOnChangeType = (pageNumber, pageSize) => {
    onPaginationChange?.({pageNumber, pageSize})
  }

  const tableChnage:TableOnChangeType = (_pagination, filters, sorter, extra) => {
    onTableChange?.({filters, sorter, extra})
  }

  return (
    <>
      <Table 
        rowKey='id'
        columns={ columns } 
        dataSource={ tableData } 
        pagination={ false }
        scroll={{y: height}}
        onChange={ tableChnage }
      />
      <Pagination 
        className={styles['pagination']}
        showSizeChanger 
        disabled={!total}
        current={ pageNumber}
        pageSize={pageSize}
        total={total} 
        showTotal={ (total) => `共${total}条记录` } 
        onChange={ paginationChange }
      />
    </>
  )
}