import type { FilterValue, SorterResult, TableCurrentDataSource } from 'antd/es/table/interface'
import type { TablePaginationConfig } from 'antd/es/table'

export interface PropsType {
    tableData: RowDataType[]
    total: number,
    pageNumber?: number,
    pageSize?: number,
    onTableChange?: EventFunctionType<[TableChangeParamsType]>,
    onPaginationChange?: EventFunctionType<[PaginationParamsType]>,
    onSwitchStatus: EventFunctionType<[{checked:boolean,row:RowDataType}]>,
    // onEditRow: EventFunctionType<[RowDataType]>,
    // onDeleteRow: EventFunctionType<[RowDataType]>
}

//  表格行数据类型
export interface RowDataType  {
    id: number,
    unionAdName: string, // 广告名称
    unionAdId: string, // 广告ID
    unionAdPosition: number, // 广告类型
    unionAppName: number, // 所属应用名称
    applicationId: number, // 所属应用id
    status: number, // 状态
    createTime: string, // 创建时间
}

//  onTableChange事件参数类型
export interface TableChangeParamsType {
    filters: Record<string, FilterValue| null>, 
    sorter: SorterResult<RowDataType> | SorterResult<RowDataType>[], 
    extra: TableCurrentDataSource<RowDataType>
}

// onPaginationChange事件参数类型
export interface PaginationParamsType {
    pageNumber: number,
    pageSize: number,
}

// ant Table 的onChange事件类型
export type TableOnChangeType = EventFunctionType<[
    TablePaginationConfig,
    Record<string, FilterValue| null>,
    SorterResult<RowDataType> | SorterResult<RowDataType>[],
    TableCurrentDataSource<RowDataType>
]>

//  ant Pagination 的onChange事件类型
export type PaginationOnChangeType = EventFunctionType<[number, number]>