import { message } from 'antd'
import http from '@src/lib/http'
import {
  adList,
  createAd as createAdPath, 
  openAd as openAdPath,
  closeAd as closeAdPath,
  allAppList,
  getAdType
} from '@src/lib/http/api'
import type { 
  AdListRequestParamsType, 
  AllAppListItemType,
  AdTypesMapType
} from './types'
import type { RowDataType } from './components/ContentTable/types'
import type { FormDataType } from './components/CreateModal/types'

export const getAdList = async (
  params: AdListRequestParamsType
): Promise<ApiResponseData<RowDataType[]>|undefined> => {
  try {
    const res = await http.get(adList, {params})
    const {data, code, msg} = res as ApiResponse<ApiResponseData<RowDataType[]>>
    if (code===0) return data
    message.error(msg ||'获取广告列表失败')
  } catch (error) { /* empty */ }
}

export const createAd = async (
  params: FormDataType
): Promise<boolean|undefined> => {
  try {
    const res = await http.post(createAdPath, params)
    const {code, msg} = res as ApiResponse<undefined>
    if (code===0) return true
    message.error(msg ||'创建广告失败')
  } catch (error) { /* empty */ }
}

export const openAd = async (
  id: number
): Promise<boolean|undefined> => {
  try {
    const res = await http.get(openAdPath, {params:{id}})
    const {code, msg} = res as ApiResponse<undefined>
    if (code===0) return true
    message.error(msg ||'开启广告失败')
  } catch (error) { /* empty */ }
}

export const clsoeAd = async (
  id: number
): Promise<boolean|undefined> => {
  try {
    const res = await http.get(closeAdPath, {params:{id}})
    const {code, msg} = res as ApiResponse<undefined>
    if (code===0) return true
    message.error(msg ||'关闭广告失败')
  } catch (error) { /* empty */ }
}

export const getAllAppList = async (): Promise<AllAppListItemType[]|undefined> => {
  try {
    const res = await http.get(allAppList)
    const {data, code, msg} = res as ApiResponse<AllAppListItemType[]>
    if (code===0) return data
    message.error(msg ||'获取全部应用列表失败')
  } catch (error) { /* empty */ }
}

export const getAdTypesMap = async (): Promise<AdTypesMapType |undefined> => {
  try {
    const res = await http.get(getAdType)
    const {data, code, msg} = res as ApiResponse<AdTypesMapType>
    if (code===0) return data
    message.error(msg ||'获取广告位列表失败')
  } catch (error) { /* empty */ }
}
