import { useEffect, useState } from 'react'
import { Space, Table, Popconfirm, Pagination } from 'antd'
import { throttle } from 'lodash'
import dayjs from 'dayjs'
import styles from './index.module.css'
import { appTypes, appStatus } from '../../const'
import type { ColumnsType } from 'antd/es/table'
import type { PropsType, RowDataType, PaginationOnChangeType, TableOnChangeType } from './types'

export default function ContentTable ({
  tableData,
  total,
  pageNumber,
  pageSize,
  onTableChange,
  onPaginationChange,
  onEditRow,
  onDeleteRow
}:PropsType) {
  const [height, setHeight] = useState(500)
  useEffect(()=>{
    const otherHeight = 60 + 64 + 48 + 48 + 55 // 预留的高度
    setHeight(window.innerHeight - otherHeight)
    const resizeEvent =throttle((e)=>{
      setHeight(e.target.innerHeight - otherHeight)
    },300)
    window.addEventListener('resize',resizeEvent)
    return ()=> window.removeEventListener('resize',resizeEvent)
  },[])

  const columns:ColumnsType<RowDataType> = [
    {
      title: '应用名称',
      dataIndex: 'unionAppName',
    },
    {
      title: '应用ID',
      dataIndex: 'unionAppId',
    },
    {
      title: '应用类型',
      dataIndex: 'thirdAppType',
      render: (v) => appTypes[v] || v
    },
    {
      title: '状态',
      dataIndex: 'status',
      render: (v) => appStatus[v] || v
    },
    {
      title: '创建时间',
      dataIndex: 'createTime',
      render: (v) => dayjs(v).format('YYYY-MM-DD HH:mm:ss')
    },
    {
      title: '操作',
      key: 'action',
      width: 120,
      render: (_v,row) => {
        return (
          <Space size='middle' >
            <a onClick={()=>{onEditRow(row)}}>编辑</a>
            <Popconfirm 
              title={`确定删除「${row.unionAppName}」这个应用？`}     
              onConfirm={ ()=>{onDeleteRow(row)} }
              okText="确认"
              cancelText="取消"
            >
              <a>删除</a>
            </Popconfirm>
          </Space>
        )
      }
    },
  ]

  const paginationChange:PaginationOnChangeType = (pageNumber, pageSize) => {
    onPaginationChange?.({pageNumber, pageSize})
  }

  const tableChnage:TableOnChangeType = (_pagination, filters, sorter, extra) => {
    onTableChange?.({filters, sorter, extra})
  }

  return (
    <>
      <Table 
        rowKey='id'
        columns={ columns } 
        dataSource={ tableData } 
        pagination={ false }
        scroll={{y: height}}
        onChange={ tableChnage }
      />
      <Pagination 
        className={styles['pagination']}
        showSizeChanger 
        disabled={!total}
        current={ pageNumber}
        pageSize={pageSize}
        total={total} 
        showTotal={ (total) => `共${total}条记录` } 
        onChange={ paginationChange }
      />
    </>
  )
}