import type { FilterValue, SorterResult, TableCurrentDataSource } from 'antd/es/table/interface'
import type { TablePaginationConfig } from 'antd/es/table'

export interface PropsType {
    tableData: RowDataType[]
    total: number,
    pageNumber?: number,
    pageSize?: number,
    onTableChange?: EventFunctionType<[TableChangeParamsType]>,
    onPaginationChange?: EventFunctionType<[PaginationParamsType]>,
    onEditRow: EventFunctionType<[RowDataType]>,
    onDeleteRow: EventFunctionType<[RowDataType]>
}

//  表格行数据类型
export interface RowDataType  {
    id: number,
    unionAppName: string, // 应用名称
    unionAppId: string, // 应用ID
    thirdAppType: number, // 应用类型
    status: number, // 状态
    createTime: string, // 创建时间
    thirdMpAppId?: string, // 小程序appid
    thirdAppDomain?: string // H5链接
}

//  onTableChange事件参数类型
export interface TableChangeParamsType {
    filters: Record<string, FilterValue| null>, 
    sorter: SorterResult<RowDataType> | SorterResult<RowDataType>[], 
    extra: TableCurrentDataSource<RowDataType>
}

// onPaginationChange事件参数类型
export interface PaginationParamsType {
    pageNumber: number,
    pageSize: number,
}

// ant Table 的onChange事件类型
export type TableOnChangeType = EventFunctionType<[
    TablePaginationConfig,
    Record<string, FilterValue| null>,
    SorterResult<RowDataType> | SorterResult<RowDataType>[],
    TableCurrentDataSource<RowDataType>
]>

//  ant Pagination 的onChange事件类型
export type PaginationOnChangeType = EventFunctionType<[number, number]>