import { useEffect, useRef, useState } from 'react'
import HeaderFilter from './components/HeaderFilter'
import ContentTable from './components/ContentTable'
import CreateModal from './components/CreateModal'
import { useGlobalStateUpdate } from '@src/store/globalStates/loadingState'
import { 
  getAppList, 
  createApp as createAppRequest,
  updateApp as updateAppRequest,
  deleteApp as deleteAppRequest
} from './request'
import type{  RefType, FormDataType } from './components/CreateModal/types'
import type { RowDataType, PaginationParamsType } from './components/ContentTable/types'

export function AppManage(){
  const [tableData, setTableData] = useState<RowDataType[]>([])
  const [total, setTotal] = useState(0)
  const [paginationParams, setPaginationParams] = useState<PaginationParamsType>({ pageNumber: 1, pageSize: 10})
  const createModalRef = useRef<RefType>()
  const setloading = useGlobalStateUpdate()

  useEffect(()=>{
    getTableData()   
  },[paginationParams])

  const  getTableData = async () => {
    setloading(true)

    const {pageNumber,pageSize} = paginationParams
    const data = await getAppList({
      pageSize,
      currentPage: pageNumber,
    })
    if (data) {
      setTableData(data.objs)
      setTotal(data.totalSize)
    }

    setloading(false)
  }

  const onPaginationChange =async (params: PaginationParamsType) => {
    setPaginationParams(params)
  }

  const onCreate = () => {
    createModalRef.current?.open()
  }

  const editRow = (row: RowDataType) => {
    createModalRef.current?.open(row)
  }

  const deleteApp = async (row: RowDataType) => {
    setloading(true)
    const res = await deleteAppRequest(row.id)
    setloading(false)
    if (res) {
      getTableData()
    }
  }

  const createApp = async (form: FormDataType, cb:EventFunctionType<[]>) => {
    setloading(true)
    const res = await createAppRequest(form)
    setloading(false)
    if (res) {
      getTableData()
      cb() // 关闭modal
    }
  }

  const updateApp = async (form: RowDataType,  cb:EventFunctionType<[]>) => {
    setloading(true)
    const {id, unionAppName} = form
    const res = await updateAppRequest({id, unionAppName})
    setloading(false)
    if (res) {
      getTableData()
      cb() // 关闭modal
    }
  }

  return (
    <>
      <HeaderFilter onCreate={onCreate} />
      <ContentTable 
        total={ total } 
        pageNumber={ paginationParams.pageNumber }
        pageSize={ paginationParams.pageSize }
        tableData={ tableData } 
        onPaginationChange = { onPaginationChange }
        onEditRow={ editRow } 
        onDeleteRow={ deleteApp }
      />
      <CreateModal 
        ref={createModalRef}
        onCreate={createApp}
        onUpdate={updateApp}
      />
    </>
  )
}
