import { message } from 'antd'
import http from '@src/lib/http'
import {
  appList,
  createApp as createAppPath, 
  updateApp as updateAppPath, 
  deleteApp as deleteAppPath
} from '@src/lib/http/api'
import type { 
  AppListRequestParamsType, 
  UpdateAppRequestParamsType 
} from './types'
import type { RowDataType } from './components/ContentTable/types'
import type { FormDataType } from './components/CreateModal/types'

export const getAppList = async (
  params: AppListRequestParamsType
): Promise<ApiResponseData<RowDataType[]>|undefined> => {
  try {
    const res = await http.get(appList, {params})
    const {data, code, msg} = res as ApiResponse<ApiResponseData<RowDataType[]>>
    if (code===0) return data
    message.error(msg ||'获取应用列表失败')
  } catch (error) { /* empty */ }
}

export const createApp = async (
  params: FormDataType
): Promise<boolean|undefined> => {
  try {
    const res = await http.post(createAppPath, params)
    const {code, msg} = res as ApiResponse<undefined>
    if (code===0) return true
    message.error(msg ||'创建应用失败')
  } catch (error) { /* empty */ }
}

export const updateApp = async (
  params: UpdateAppRequestParamsType
): Promise<boolean|undefined> => {
  try {
    const res = await http.post(updateAppPath, params)
    const {code, msg} = res as ApiResponse<undefined>
    if (code===0) return true
    message.error(msg ||'修改应用失败')
  } catch (error) { /* empty */ }
}

export const deleteApp = async (
  id: number
): Promise<boolean|undefined> => {
  try {
    const res = await http.delete(deleteAppPath, {params:{id}})
    const {code, msg} = res as ApiResponse<undefined>
    if (code===0) return true
    message.error(msg ||'删除应用失败')
  } catch (error) { /* empty */ }
}

