import React, { useState, createContext, useContext, PropsWithChildren } from 'react'

// 构造器函数，用于创建全局状态管理钩子
function createGlobalStateHook<T>(initialState?: T) {
  const GlobalStateContext = createContext<T|undefined>(initialState)
  const GlobalStateUpdateContext = createContext<React.Dispatch<React.SetStateAction<T|undefined>>>(() => {})


  function useGlobalState() {
    return useContext(GlobalStateContext)
  }

  function useGlobalStateUpdate() {
    return useContext(GlobalStateUpdateContext)
  }

  function GlobalStateProvider({ children }: PropsWithChildren) {
    const [globalState, setGlobalState] = useState(initialState)

    return (
      <GlobalStateContext.Provider value={globalState}>
        <GlobalStateUpdateContext.Provider value={setGlobalState}>
          {children}
        </GlobalStateUpdateContext.Provider>
      </GlobalStateContext.Provider>
    )
  }

  return {
    useGlobalState,
    useGlobalStateUpdate,
    GlobalStateProvider,
  }
}

export default createGlobalStateHook
